
# DO NOT EDIT THIS FILE -- AUTOGENERATED BY PANTS
# Target: src/concourse:ol-concourse

from setuptools import setup

setup(**{
    'install_requires': (
        'pydantic<2.0.0,>=1',
    ),
    'name': 'ol-concourse',
    'namespace_packages': (
    ),
    'package_data': {
    },
    'packages': (
        'concourse',
        'concourse.lib',
        'concourse.lib.models',
    ),
    'python_requires': '>=3.9',
    'version': '0.1.0',
})
